# pymatrix-rain
Matrix rain effect using python 3 and curses.

### How to Download
 >pip install pymatrix-rain
 
 to run: pymatrix-rain


##### NOTE:

> not tested on windows or mac


###  Commands
- **<kbd>Q</kbd>** = *quits*
- **<kbd>b</kbd>** = *bold on*
- **<kbd>B</kbd>** = *bold all*
- **<kbd>n</kbd>** = *bold off*
- **<kbd>0-9</kbd>** = *delay speed*
- **<kbd>a</kbd>** = *asynchronous like scrolling*
- **<kbd>m</kbd>** = *multiple color mode*
- **<kbd>M</kbd>** = *multiple random color mode*
- **<kbd>d</kbd>** = *reset to default*
- **<kbd>c</kbd>** = *cycle through colors automatically*
- **<kbd>l</kbd>** = *toggle double space lines*
- **<kbd>e</kbd>** = *toggle extended characters*
- **<kbd>E</kbd>** = *only extended characters if on*
- **<kbd>z</kbd>** = *Zero and One Mode On*
- **<kbd>Z</kbd>** = *Zero and One Mode Off*
- **<kbd>f</kbd>** = *Freeze and unfreeze the matrix. Can still use **<kbd>Q</kbd>** to quit.*
- **<kbd>v</kbd>** = *Toggle the matrix to scroll up*
- **<kbd>shift 0-9</kbd>** = *cycle color delay*

##### rain colors
- **<kbd>r</kbd>** = red
- **<kbd>t</kbd>** = green
- **<kbd>y</kbd>** = blue
- **<kbd>u</kbd>** = yellow
- **<kbd>i</kbd>** = magenta
- **<kbd>o</kbd>** = cyan
- **<kbd>p</kbd>** = white

##### lead char color
- **<kbd>R</kbd>** = red
- **<kbd>T</kbd>** = green
- **<kbd>Y</kbd>** = blue
- **<kbd>U</kbd>** = yellow
- **<kbd>I</kbd>** = magenta
- **<kbd>O</kbd>** = cyan
- **<kbd>P</kbd>** = white

##### background colors
- **<kbd>ctrl-r</kbd>** = red
- **<kbd>ctrl-t</kbd>** = green
- **<kbd>ctrl-y</kbd>** = blue
- **<kbd>ctrl-u</kbd>** = yellow
- **<kbd>ctrl-i</kbd>** = magenta
- **<kbd>ctrl-o</kbd>** = cyan
- **<kbd>ctrl-p</kbd>** = white

## Screen Shots
![matrix1.png](https://i.fluffy.cc/Vs2ZW5PBdM0QXv7Ljz3LDV7JCg2LJBJK.png)

![matrix2.png](https://i.fluffy.cc/LWwpSxJldKBBVlC260Zc7T5CRg7JN303.png)

![matrix3.png](https://i.fluffy.cc/K0MNwrm4KC69NZRQm1k3JsR9j1FqxjWm.png)

![matrix4.png](https://i.fluffy.cc/h582RvNQxqcsX5029wcK9q0v2kBPcRMd.png)

![matrix5.png](https://i.fluffy.cc/q7xjhc011J6N5nP53dDKrnnJNX7Qp5t3.png)

![matrix6.png](https://i.fluffy.cc/JdRwzdWxltVxc80RDGg7BDB41hZMFmNN.png)
